@@ -1,4 +1,4 @@
-/* $Id: gtkmm.h,v 1.27 2002/11/28 14:06:23 murrayc Exp $ */
+/* $Id: gtkmm.h,v 1.3 2003/10/17 16:18:19 murrayc Exp $ */
 /* gtkmm - a C++ wrapper for the Gtk toolkit
  *
  * Copyright 1999-2002 The gtkmm Development Team
@@ -47,18 +47,24 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/cellrendererpixbuf.h>
 #include <gtkmm/cellrenderertext.h>
 #include <gtkmm/cellrenderertoggle.h>
+#include <gtkmm/colorbutton.h>
 #include <gtkmm/colorselection.h>
-#include <gtkmm/combo.h>
+#include <gtkmm/combo.h> //TODO: Deprecated.
+#include <gtkmm/combobox.h>
+#include <gtkmm/combobox.h>
+#include <gtkmm/comboboxtext.h>
 #include <gtkmm/container.h>
 #include <gtkmm/curve.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/drawingarea.h>
 #include <gtkmm/editable.h>
 #include <gtkmm/entry.h>
+#include <gtkmm/expander.h>
 #include <gtkmm/enums.h>
 #include <gtkmm/eventbox.h>
 #include <gtkmm/fileselection.h>
 #include <gtkmm/fixed.h>
+#include <gtkmm/fontbutton.h>
 #include <gtkmm/fontselection.h>
 #include <gtkmm/frame.h>
 //#include <gtkmm/rc.h>
@@ -87,6 +93,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/optionmenu.h>
 #include <gtkmm/paned.h>
 #include <gtkmm/progressbar.h>
+#include <gtkmm/radioaction.h>
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/radiomenuitem.h>
 #include <gtkmm/range.h>
@@ -111,6 +118,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/texttag.h>
 #include <gtkmm/texttagtable.h>
 #include <gtkmm/textview.h>
+#include <gtkmm/toggleaction.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/toolbar.h>
 #include <gtkmm/tooltips.h>
@@ -121,6 +129,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/treestore.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/treeviewcolumn.h>
+#include <gtkmm/uimanager.h>
 #include <gtkmm/viewport.h>
 #include <gtkmm/widget.h>
 #include <gtkmm/window.h>
